
from django.contrib import admin
from django import forms

from email_extras.settings import USE_GNUPG, GNUPG_HOME


if USE_GNUPG:
    from gnupg import GPG
    from email_extras.models import Key, Address
    from email_extras.utils import addresses_for_key

    class KeyAdmin(admin.ModelAdmin):

        def save_model(self, request, obj, form, change):
            """
            Import the key and parse the addresses from it and save
            them, and omit the super save_model call so as to never
            save the key instance.
            """
            gpg = GPG(gnupghome=GNUPG_HOME)
            result = gpg.import_keys(obj.key)
            if result.count == 0:
                raise forms.ValidationError("Invalid Key")
            else:
                addresses = []
                for key in result.results:
                    addresses.extend(addresses_for_key(gpg, key))
                obj.addresses = ",".join(addresses)
                for address in addresses:
                    Address.objects.get_or_create(address=address)

    admin.site.register(Key, KeyAdmin)
    admin.site.register(Address)




from django.db import models

from email_extras.settings import USE_GNUPG, GNUPG_HOME


if USE_GNUPG:
    from gnupg import GPG

    class Key(models.Model):
        """
        Accepts a key and imports it via admin's save_model which
        omits saving.
        """

        key = models.TextField()
        addresses = models.TextField(editable=False)

        def __unicode__(self):
            return self.addresses


    class Address(models.Model):
        """
        Stores the address for a successfully imported key and allows
        deletion.
        """

        class Meta:
            verbose_name_plural = "Addresses"

        address = models.CharField(max_length=200)

        def __unicode__(self):
            return self.address

        def delete(self):
            """
            Remove any keys for this address.
            """
            from email_extras.utils import addresses_for_key
            gpg = GPG(gnupghome=GNUPG_HOME)
            for key in gpg.list_keys():
                if self.address in addresses_for_key(gpg, key):
                    gpg.delete_keys(key["fingerprint"], True)
                    gpg.delete_keys(key["fingerprint"])
            super(Address, self).delete()




__version__ = "0.1.3"


try:
    from email_extras.settings import USE_GNUPG
except ImportError:
    pass
else:
    if USE_GNUPG:
        try:
            import gnupg
        except ImportError:
            raise ImproperlyConfigured, "Could not import gnupg"


